==> dhall-lsp-server-1.1.4-3-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-lsp-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-lsp-server
version:              1.1.4
visibility:           public
id:                   dhall-lsp-server-1.1.4-7J2NaE3VVViEJdSnbKdhTI
key:                  dhall-lsp-server-1.1.4-7J2NaE3VVViEJdSnbKdhTI
license:              MIT
copyright:            2019 panaeon
maintainer:           Gabriella Gonzalez
author:               panaeon
homepage:
    https://github.com/dhall-lang/dhall-haskell/tree/master/dhall-lsp-server#readme

synopsis:             Language Server Protocol (LSP) server for Dhall
abi:                  1de0c9ba327a95f109ba17580f291c9e
exposed:              True
exposed-modules:
    Dhall.LSP.Backend.Completion Dhall.LSP.Backend.Dhall
    Dhall.LSP.Backend.Diagnostics Dhall.LSP.Backend.Formatting
    Dhall.LSP.Backend.Freezing Dhall.LSP.Backend.Linting
    Dhall.LSP.Backend.Parsing Dhall.LSP.Backend.ToJSON
    Dhall.LSP.Backend.Typing Dhall.LSP.Handlers Dhall.LSP.Server
    Dhall.LSP.State

hidden-modules:       Paths_dhall_lsp_server Dhall.LSP.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-lsp-server-1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-lsp-server-1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-lsp-server-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-lsp-server
hs-libraries:         HSdhall-lsp-server-1.1.4-7J2NaE3VVViEJdSnbKdhTI
depends:
    aeson-2.1.2.1-F9MXb1A8ug6GkYytoGh4jA
    aeson-pretty-0.8.10-3IneY4B7RymIuXlHqWnLhh base-4.17.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.5-EUhrJ5THpPT6kmMqMqPsv7
    containers-0.6.7 data-default-0.7.1.2-7c115eFpvxq7Z5z0er1qPt
    dhall-1.42.2-KMY04THIxy77tFNXpglzEq
    dhall-json-1.7.12-FjiqdOIq2Z0EPfVcbhhXPL directory-1.3.7.1
    filepath-1.4.2.2 lens-5.3-HdczP0no6IA6OsB2lfUnLL
    lsp-2.1.0.0-gI4sjr8ace9num3GDSHxI
    megaparsec-9.6.1-62V38K3gknlIcNW2QJXG5P mtl-2.2.2
    network-uri-2.6.4.2-L8nDuI5zE9yEZ3pwnnu7AU
    prettyprinter-1.7.1-3W0ElPC5NNG6rVoiMzjO1q text-2.0.2
    text-rope-0.3-7b7rzGmzDO85FKxlus88gh transformers-0.5.6.2
    unordered-containers-0.2.20-Kb1zmdIZFsX5Z4trT8w0xB
    uri-encode-1.5.0.7-5WzIB0YcO0zG2nDVZ5NQaE

haddock-interfaces:
    /usr/share/doc/dhall-lsp-server/html/dhall-lsp-server.haddock

haddock-html:         /usr/share/doc/dhall-lsp-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-lsp-server-1.1.4-4-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-lsp-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-lsp-server
version:              1.1.4
visibility:           public
id:                   dhall-lsp-server-1.1.4-JlOy1o9P7xjGa4yGAL6Tml
key:                  dhall-lsp-server-1.1.4-JlOy1o9P7xjGa4yGAL6Tml
license:              MIT
copyright:            2019 panaeon
maintainer:           Gabriella Gonzalez
author:               panaeon
homepage:
    https://github.com/dhall-lang/dhall-haskell/tree/master/dhall-lsp-server#readme

synopsis:             Language Server Protocol (LSP) server for Dhall
abi:                  cdfc72c8b916fe57cbb664ea02afeaf9
exposed:              True
exposed-modules:
    Dhall.LSP.Backend.Completion Dhall.LSP.Backend.Dhall
    Dhall.LSP.Backend.Diagnostics Dhall.LSP.Backend.Formatting
    Dhall.LSP.Backend.Freezing Dhall.LSP.Backend.Linting
    Dhall.LSP.Backend.Parsing Dhall.LSP.Backend.ToJSON
    Dhall.LSP.Backend.Typing Dhall.LSP.Handlers Dhall.LSP.Server
    Dhall.LSP.State

hidden-modules:       Paths_dhall_lsp_server Dhall.LSP.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-lsp-server-1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-lsp-server-1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-lsp-server-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-lsp-server
hs-libraries:         HSdhall-lsp-server-1.1.4-JlOy1o9P7xjGa4yGAL6Tml
depends:
    aeson-2.1.2.1-HPwo2VO3hzcFr4fiGB5Oro
    aeson-pretty-0.8.10-6mqlJbaGBfr9VazENxXqaY base-4.17.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.5-LpN8aQdBw01LbI15npD2uy
    containers-0.6.7 data-default-0.7.1.2-7c115eFpvxq7Z5z0er1qPt
    dhall-1.42.2-CEq1VwR4o8A9qw1L2CqSap
    dhall-json-1.7.12-8EY8BCBLnPu5GmU02M4pTw directory-1.3.7.1
    filepath-1.4.2.2 lens-5.3-pl18ecYYzn8sW5PtrryAE
    lsp-2.1.0.0-DnlBzEwRSs1GzYbMC2TL46
    megaparsec-9.6.1-EACNQE4V0s4sorPNkNSJS mtl-2.2.2
    network-uri-2.6.4.2-2s4BpOjYszS9lLOXbJJXzp
    prettyprinter-1.7.1-CblNKNR1eKT9nxUoBiyJi9 text-2.0.2
    text-rope-0.3-ALF9SjbDbJQ6pIFGNI4Wxw transformers-0.5.6.2
    unordered-containers-0.2.20-FFF0GulGLFtAHq6N1Lkm0s
    uri-encode-1.5.0.7-AuXfE3mjZVO3WTVLdEDkbE

haddock-interfaces:
    /usr/share/doc/dhall-lsp-server/html/dhall-lsp-server.haddock

haddock-html:         /usr/share/doc/dhall-lsp-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
